@@ -33,7 +33,7 @@ class Client:
 
 	def wait_for_ganot_task(self, ganot_task_id, timeout=60):
 
-		while(True):
+		while True:
 			gt = self.ganottask_get(ganot_task_id)
 			if gt['state'] == 'succeeded':
 				return gt
@@ -126,6 +126,38 @@ class Client:
 		jesponse = self._response_check_json(response)
 		return jesponse['taskId']
 
+	def radiospace_get(self):
+
+		payload = ""
+		headers = {
+			'cache-control': "no-cache",
+		}
+		response = self.session.request("GET", self.server_url + "/radiospace/get", data=payload, headers=headers)
+		self._response_check(response)
+		return response.json()
+
+	def radiospace_statistics_for_file(self, format, radiospace_id, filename):
+
+		files = {'files': open(filename, 'rb') }
+		headers = {
+			'X-XSRF-TOKEN': self.xsrf_token,
+			'cache-control': "no-cache"
+		}
+		response = self.session.request("POST", self.server_url + "/radiospace/statisticsForFile/{}/{}".format(format, radiospace_id), files=files, headers=headers)
+		jesponse = self._response_check_json(response)
+		return jesponse['taskId']
+
+	def customflight_persist(self, ganot_task_id, name):
+
+		headers = {
+			'X-XSRF-TOKEN': self.xsrf_token,
+			'cache-control': "no-cache",
+			'Content-Type': "application/json"
+		}
+		response = self.session.request("POST", self.server_url + "/custom-flight/ganotTaskId/{}/name/{}/preview/false".format(ganot_task_id, urllib.parse.quote(name)), headers=headers)
+		self._response_check(response)
+		return response.json()
+
 	def ganottask_get(self, ganot_task_id):
 
 		payload = ""
